==> huaweicloudsdkevs-3.1.47-py2.py3-none-any.whl: huaweicloudsdkevs/v2/model/cinder_accept_volume_transfer_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CinderAcceptVolumeTransferResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'transfer': 'VolumeTransferSummary'
    }

    attribute_map = {
        'transfer': 'transfer'
    }

    def __init__(self, transfer=None):
        """CinderAcceptVolumeTransferResponse

        The model defined in huaweicloud sdk

        :param transfer: 
        :type transfer: :class:`huaweicloudsdkevs.v2.VolumeTransferSummary`
        """
        
        super(CinderAcceptVolumeTransferResponse, self).__init__()

        self._transfer = None
        self.discriminator = None

        if transfer is not None:
            self.transfer = transfer

    @property
    def transfer(self):
        """Gets the transfer of this CinderAcceptVolumeTransferResponse.

        :return: The transfer of this CinderAcceptVolumeTransferResponse.
        :rtype: :class:`huaweicloudsdkevs.v2.VolumeTransferSummary`
        """
        return self._transfer

    @transfer.setter
    def transfer(self, transfer):
        """Sets the transfer of this CinderAcceptVolumeTransferResponse.

        :param transfer: The transfer of this CinderAcceptVolumeTransferResponse.
        :type transfer: :class:`huaweicloudsdkevs.v2.VolumeTransferSummary`
        """
        self._transfer = transfer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CinderAcceptVolumeTransferResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkevs-3.1.143-py2.py3-none-any.whl: huaweicloudsdkevs/v2/model/cinder_accept_volume_transfer_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CinderAcceptVolumeTransferResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'transfer': 'VolumeTransferSummary'
    }

    attribute_map = {
        'transfer': 'transfer'
    }

    def __init__(self, transfer=None):
        r"""CinderAcceptVolumeTransferResponse

        The model defined in huaweicloud sdk

        :param transfer: 
        :type transfer: :class:`huaweicloudsdkevs.v2.VolumeTransferSummary`
        """
        
        super(CinderAcceptVolumeTransferResponse, self).__init__()

        self._transfer = None
        self.discriminator = None

        if transfer is not None:
            self.transfer = transfer

    @property
    def transfer(self):
        r"""Gets the transfer of this CinderAcceptVolumeTransferResponse.

        :return: The transfer of this CinderAcceptVolumeTransferResponse.
        :rtype: :class:`huaweicloudsdkevs.v2.VolumeTransferSummary`
        """
        return self._transfer

    @transfer.setter
    def transfer(self, transfer):
        r"""Sets the transfer of this CinderAcceptVolumeTransferResponse.

        :param transfer: The transfer of this CinderAcceptVolumeTransferResponse.
        :type transfer: :class:`huaweicloudsdkevs.v2.VolumeTransferSummary`
        """
        self._transfer = transfer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CinderAcceptVolumeTransferResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
